@@ -1,8 +1,9 @@
 use strict;
 use warnings;
+use version;
 
 package WebService::Nestoria::Search;
-$WebService::Nestoria::Search::VERSION = '1.022008';
+$WebService::Nestoria::Search::VERSION = '1.022009';
 use Carp;
 use URI;
 use WebService::Nestoria::Search::Request;
@@ -14,7 +15,7 @@ WebService::Nestoria::Search - Perl interface to the Nestoria Search public API.
 
 =head1 VERSION
 
-version 1.022008
+version 1.022009
 
 =head1 SYNOPSIS
 
@@ -122,7 +123,12 @@ C<@listings> is an array of WebService::Nestoria::Search::Result objects.
 ## Configuration details for searching the Nestoria listings database
 ##
 my %Config = (
-    'AppId'                   => "WebService::Nestoria::Search $WebService::Nestoria::Search::VERSION",
+    'AppId'                   => sprintf("%s %s",
+        __PACKAGE__,
+        $WebService::Nestoria::Search::VERSION
+            ? version->parse($WebService::Nestoria::Search::VERSION)->normal
+            : ""
+    ),
     'MaxResults'              => '1000',
 
     ## keys indicate the universe of allowable arguments
@@ -164,7 +170,6 @@ my %Config = (
         'fr'                  => 'http://api.nestoria.fr/api',
         'in'                  => 'http://api.nestoria.in/api',
         'it'                  => 'http://api.nestoria.it/api',
-        'mx'                  => 'http://api.nestoria.mx/api',
         'uk'                  => 'http://api.nestoria.co.uk/api',
     },
 );
@@ -658,14 +663,14 @@ Currently the available countries are:
 
 =item * it - Italy
 
-=item * mx - Mexico
-
 =item * uk - United Kingdom
 
 =back
 
 Australia (au) supports the metadata requests but not listings requests
 
+Mexico (mx) currently has no API support.
+
 =head1 Non-OO
 
 It is possible to run WebService::Nestoria::Search functions without creating an object. However, no functions are exported (by default or otherwise) so the full name must be used.
